/*
 * Note: this file originally auto-generated by mib2c using
 *       version : 17337 $ of $
 *
 * $Id:$
 */
/** \page MFD helper for ieee8021BridgeBaseTable
 *
 * \section intro Introduction
 * Introductory text.
 *
 */
/* standard Net-SNMP includes */
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

/* include our parent header */
#include "ieee8021BridgeBaseTable.h"

#include <net-snmp/agent/mib_modules.h>

#include "ieee8021BridgeBaseTable_interface.h"

const oid ieee8021BridgeBaseTable_oid[] = { IEEE8021BRIDGEBASETABLE_OID };
const int ieee8021BridgeBaseTable_oid_size = OID_LENGTH(ieee8021BridgeBaseTable_oid);

    ieee8021BridgeBaseTable_registration  ieee8021BridgeBaseTable_user_context;

void initialize_table_ieee8021BridgeBaseTable(void);
void shutdown_table_ieee8021BridgeBaseTable(void);


/**
 * Initializes the ieee8021BridgeBaseTable module
 */
void
init_ieee8021BridgeBaseTable(void)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeBaseTable:init_ieee8021BridgeBaseTable","called\n"));

    /*
     * TODO:300:o: Perform ieee8021BridgeBaseTable one-time module initialization.
     */

    /*
     * here we initialize all the tables we're planning on supporting
     */
    if (should_init("ieee8021BridgeBaseTable"))
        initialize_table_ieee8021BridgeBaseTable();

} /* init_ieee8021BridgeBaseTable */

/**
 * Shut-down the ieee8021BridgeBaseTable module (agent is exiting)
 */
void
shutdown_ieee8021BridgeBaseTable(void)
{
    if (should_init("ieee8021BridgeBaseTable"))
        shutdown_table_ieee8021BridgeBaseTable();

}

/**
 * Initialize the table ieee8021BridgeBaseTable
 *    (Define its contents and how it's structured)
 */
void
initialize_table_ieee8021BridgeBaseTable(void)
{
    ieee8021BridgeBaseTable_registration * user_context;
    u_long flags;

    DEBUGMSGTL(("verbose:ieee8021BridgeBaseTable:initialize_table_ieee8021BridgeBaseTable","called\n"));

    /*
     * TODO:301:o: Perform ieee8021BridgeBaseTable one-time table initialization.
     */

    /*
     * TODO:302:o: |->Initialize ieee8021BridgeBaseTable user context
     * if you'd like to pass in a pointer to some data for this
     * table, allocate or set it up here.
     */
    /*
     * a netsnmp_data_list is a simple way to store void pointers. A simple
     * string token is used to add, find or remove pointers.
     */
    user_context = netsnmp_create_data_list("ieee8021BridgeBaseTable", NULL, NULL);

    /*
     * No support for any flags yet, but in the future you would
     * set any flags here.
     */
    flags = 0;

    /*
     * call interface initialization code
     */
    _ieee8021BridgeBaseTable_initialize_interface(user_context, flags);
} /* initialize_table_ieee8021BridgeBaseTable */

/**
 * Shutdown the table ieee8021BridgeBaseTable
 */
void
shutdown_table_ieee8021BridgeBaseTable(void)
{
    /*
     * call interface shutdown code
     */
    _ieee8021BridgeBaseTable_shutdown_interface(&ieee8021BridgeBaseTable_user_context);
}

/**
 * extra context initialization (eg default values)
 *
 * @param rowreq_ctx    : row request context
 * @param user_init_ctx : void pointer for user (parameter to rowreq_ctx_allocate)
 *
 * @retval MFD_SUCCESS  : no errors
 * @retval MFD_ERROR    : error (context allocate will fail)
 */
int
ieee8021BridgeBaseTable_rowreq_ctx_init(ieee8021BridgeBaseTable_rowreq_ctx *rowreq_ctx,
                           void *user_init_ctx)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeBaseTable:ieee8021BridgeBaseTable_rowreq_ctx_init","called\n"));

    netsnmp_assert(NULL != rowreq_ctx);

    /*
     * TODO:210:o: |-> Perform extra ieee8021BridgeBaseTable rowreq initialization. (eg DEFVALS)
     */
    rowreq_ctx->data.ieee8021BridgeBaseTrafficClassesEnabled = TRUTHVALUE_TRUE;

    rowreq_ctx->data.ieee8021BridgeBaseMmrpEnabledStatus = TRUTHVALUE_TRUE;


    return MFD_SUCCESS;
} /* ieee8021BridgeBaseTable_rowreq_ctx_init */

/**
 * extra context cleanup
 *
 */
void ieee8021BridgeBaseTable_rowreq_ctx_cleanup(ieee8021BridgeBaseTable_rowreq_ctx *rowreq_ctx)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeBaseTable:ieee8021BridgeBaseTable_rowreq_ctx_cleanup","called\n"));

    netsnmp_assert(NULL != rowreq_ctx);

    /*
     * TODO:211:o: |-> Perform extra ieee8021BridgeBaseTable rowreq cleanup.
     */
} /* ieee8021BridgeBaseTable_rowreq_ctx_cleanup */

/**
 * pre-request callback
 *
 *
 * @retval MFD_SUCCESS              : success.
 * @retval MFD_ERROR                : other error
 */
int
ieee8021BridgeBaseTable_pre_request(ieee8021BridgeBaseTable_registration * user_context)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeBaseTable:ieee8021BridgeBaseTable_pre_request","called\n"));

    /*
     * TODO:510:o: Perform ieee8021BridgeBaseTable pre-request actions.
     */

    return MFD_SUCCESS;
} /* ieee8021BridgeBaseTable_pre_request */

/**
 * post-request callback
 *
 * Note:
 *   New rows have been inserted into the container, and
 *   deleted rows have been removed from the container and
 *   released.
 *
 * @param user_context
 * @param rc : MFD_SUCCESS if all requests succeeded
 *
 * @retval MFD_SUCCESS : success.
 * @retval MFD_ERROR   : other error (ignored)
 */
int
ieee8021BridgeBaseTable_post_request(ieee8021BridgeBaseTable_registration * user_context, int rc)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeBaseTable:ieee8021BridgeBaseTable_post_request","called\n"));

    /*
     * TODO:511:o: Perform ieee8021BridgeBaseTable post-request actions.
     */

    /*
     * check to set if any rows were changed.
     */
    if (ieee8021BridgeBaseTable_dirty_get()) {
        /*
         * check if request was successful. If so, this would be
         * a good place to save data to its persistent store.
         */
        if (MFD_SUCCESS == rc) {
            /*
             * save changed rows, if you haven't already
             */
        }

        ieee8021BridgeBaseTable_dirty_set(0); /* clear table dirty flag */
    }

    return MFD_SUCCESS;
} /* ieee8021BridgeBaseTable_post_request */


/** @{ */
